<?php

# ***** BEGIN LICENSE BLOCK *****
# This file is part of linkSwitcher plugin for DotClear 1.2.3.
# Copyright (c) 2006 Mikal Pirio and contributors. All rights
# reserved.
#
# linkSwitcher is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# linkSwitcher is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with linkSwitcher; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****

class linkSwitcher {

	/**	
	@function readConf

	Cette fonction permet de lire le fichier de configuration d'arcSwitcher
	*/
	function readConf(){
		$linkSwitcher_config_file = DC_SHARE_DIR.'/linkSwitcher/linkSwitcher.conf';

		$os = (DIRECTORY_SEPARATOR == '\\') ? 'win' : 'nix';
		
		# Transformation du chemin, forme std
		if ($os == 'win') $linkSwitcher_config_file = str_replace('/','\\',$linkSwitcher_config_file);

		if ( !file_exists($linkSwitcher_config_file) ) {
			return false;
		}

		$linkSwitcher_config = new iniFile($linkSwitcher_config_file);
		$linkSwitcher_config->read($linkSwitcher_config_file);

		if ( !defined('LS_ACTIVE_JS') ||  !defined('LS_FIRST') ||
		     !defined('LS_LABEL_SUBMIT') ) {
			return false;
		}

		return true;
	}



	/**
	@function  linkList

	Cette fonction affiche la liste des liens, soit comme la mthode
	dcBlogRoll::linkList() de DotClear ou sous forme de liste droulante,
	ou les deux.

	@param    mixed    link_select  Liens  afficher en tant que liste droulante.
	                                Ce paramtre peut tre :
	                                   + un tableau (listant les url des liens)
	                                   + une expression rgulire (base sur
	                                     les urls des liens)
	                                     ssi $regex_mode = true
	                                   + la valeur 'ALL' pour tous les liens

	@param    boolean  regex_mode   Active ou non le mode regex (true|false)

	@param    string   links_block  Mise en forme du bloc "Liens" avec les
	                                liens en dehors et dedans la liste
	                                droulante (%1$s correspond aux liens en
	                                affichage normal et %2$d correspond  la
	                                liste droulante

	@param    string   category     Mise en forme d'une catgorie
	                                (cf dcBlogRoll::linkList())

	@param    string   block        Mise en forme de la liste des liens non
	                                compris dans la liste droulante
	
	@param    string   item         Mise en forme des lments de la liste des
	                                liens non compris dans la liste droulante
	*/

	function linkList( $links_select='', $regex_mode=false, 
	                   $links_block='%1$s<br />%2$s',
	                   $category='<h3>%s</h3>',
	                   $block='<ul>%s</ul>', $item='<li>%s</li>') {

		global $con, $blog;

		$req = 'SELECT link_id, label, href, title, lang, rel '.
		       'FROM '.$blog->t_link.' '.
	         'ORDER BY position';

		if ( ($rs_link = $con->select($req)) !== false ) {

			// le formulaire qui contiendra la liste droulante et le bouton optionnel
			$form  = '';
			// $liens va contenir les tags qui sont en dehors de la liste droulante
			$liens = '';
			// $list va contenir la liste des <option>...</option> et <optgroup>
			$list  = '';
			// Pour savoir si list est vide ou non
			$empty_list = true;

			# read configuration file
			$conf = linkSwitcher::readConf();

			/* si la conf n'a pas pu tre lue, on va simplement afficher les archives
			   comme avec la fonction d'origine, donc pas besoin des <option>...</option>
			   et Cie */
			if($conf) {
				// AS_FIRST value of the drop-down list
				$list = '<option value="" >'.LS_FIRST.'</option>';
			}

			$cat = '';

			# var pour savoir si on est dans une catgorie
			$in_cat = false;
			# vars pour savoir si une catgorie est vide ou non, dans la liste ou dans l'affichage
			# normal. Si elle est vide, on ne l'afiche pas
			$empty_cat_in_list   = true;
			$empty_cat_in_normal = true;

			while (!$rs_link->EOF()) {

				$id    = $rs_link->f('link_id');
				$label = $rs_link->f('label');
				$href  = $rs_link->f('href');
				$title = $rs_link->f('title');
				$lang  = $rs_link->f('lang');
				$rel   = $rs_link->f('rel');

				if( !$label && !$href ) {
					# si y'a pas de label ni de lien, c'est une catgorie :)
					if($in_cat) {
						if($conf && !$empty_cat_in_list) $list.='</optgroup>'; // on ferme la catgorie prcdente
						$empty_cat_in_list   = true;
						$empty_cat_in_normal = true;
					}
					$cat = $title;
					$in_cat = true;
				}
				else {
					if ( $conf && 
							 ( $links_select === 'ALL' ) ||
					     ( is_array($links_select) && in_array($href, $links_select) ) ||
					     ( $regex_mode && ereg($links_select,$href) )
					   ) {
					   	
					  $empty_list = false;
					   	
						if($in_cat && $empty_cat_in_list) {
							// on entre dans ce bloc si on est sur le premier lien d'une catgorie
							// donc on crit un <optgroup ... pour dsigner la catgorie 
							$list.= '<optgroup label="'.$cat.'">';
							$empty_cat_in_list = false;  // utile pour ne pas rerentrer dans ce bloc la prochaine fois, s'il y a un second lien dans cette catgorie
						}

						$list.='<option id="lS_option_'.$id.'" '.
						       'label="'.$label.'" '.
						       'value="'.$id.'" '.
						       'title="'.htmlspecialchars($title).'" '.
						       'lang="'.htmlspecialchars($lang).'" >'.
						       $label.
						       '</option>';
					}
					else {
						if($in_cat && $empty_cat_in_normal) {
							$liens .= sprintf($category, $cat);
							$empty_cat_in_normal = false;
						}

						$lien = '<a href="'.htmlspecialchars($href).'"'.
						        ((!$lang) ? '' : ' hreflang="'.htmlspecialchars($lang).'"').
						        ((!$title) ? '' : ' title="'.htmlspecialchars($title).'"').
						        ((!$rel) ? '' : ' rel="'.htmlspecialchars($rel).'"').
						        '>'.htmlspecialchars($label).'</a>';

						$liens .= sprintf($item,$lien);
					}
				}
				$rs_link->moveNext();
			}
			
			if ( $conf && !$empty_list){
			
				if($in_cat && !$empty_cat_in_list) $list.='</optgroup>';

				$form = '<form id="lS_form" method="post" action="'.dc_app_url.'/ecrire/tools/linkSwitcher/redirect.php" >'."\n".
			          '<p id="lS_p_form">'."\n".
			          '<select id="lS_select" name="link" size="1" ';
			          
			  if(LS_ACTIVE_JS) $form.= 'onchange="this.form.submit();"';
			  
			  $form.= ' >'."\n".
			          $list."\n".
			          '</select>'."\n".
			          '<input id="lS_submit" type="submit" value="'.LS_LABEL_SUBMIT.'" />'."\n".
			          '</p>'."\n".
			          '</form>'."\n";
			          
			}

			if( $liens != '') $liens = sprintf($block, $liens);

			printf($links_block,$liens,$form);
		}
	}


	/**
	@function       hideSubmitButton

	Cette fonction permet d'afficher ou non le bouton "Go" (ou "Aller" en franais :) )
	affich  ct de la liste droulante. Cette fonction permet simplement d'inclure un
	fichier javascript qui :

		1 - Si javascript est activ et le paramtre active de la fonction est  true, permet
		    d'effacer el bouton ( l'aide de DOM et Cie)

		2 - Si javascript est activ et le paramtre active est  false, laisse le bouton

		3 - si javascript n'est pas activ, affiche le bouton.

*/


	function hideSubmitButton(){
		# read conf
		if ( !($conf = linkSwitcher::readConf()) ) exit;
		
		if (LS_ACTIVE_JS)
			echo '  <script src="'.dc_app_url.'/ecrire/tools/linkSwitcher/linkSwitcher.js" type="text/javascript"></script>'."\n"; 
	}

}

?>
